Module: ActsAsList::InstanceMethods

Included in:
ActsAsList
Defined in:
lib/instance_methods.rb

Overview

All the methods available to a record that has had acts_as_list specified. Each method works by assuming the object to be the item in the list, so chapter.move_lower would move that chapter lower in the list of all chapters. Likewise, chapter.first? would return true if that chapter is the first in the list of all chapters.

Instance Method Summary collapse

Instance Method Details

#decrement_positionObject

Decrease the position of this item without adjusting the rest of the list.



67
68
69
70
# File 'lib/instance_methods.rb', line 67

def decrement_position
  return unless in_list?
  update_attribute position_column, self.send(position_column).to_i - 1
end

#first?Boolean

Return true if this object is the first in the list.

Returns:

  • (Boolean)


73
74
75
76
# File 'lib/instance_methods.rb', line 73

def first?
  return false unless in_list?
  self.send(position_column) == 1
end

#higher_itemObject

Return the next higher item in the list.



85
86
87
88
89
90
# File 'lib/instance_methods.rb', line 85

def higher_item
  return nil unless in_list?
  acts_as_list_class.find(:first, :conditions =>
    "#{scope_condition} AND #{position_column} = #{(send(position_column).to_i - 1).to_s}"
  )
end

#in_list?Boolean

Test if this record is in a list

Returns:

  • (Boolean)


101
102
103
# File 'lib/instance_methods.rb', line 101

def in_list?
  !send(position_column).nil?
end

#increment_positionObject

Increase the position of this item without adjusting the rest of the list.



61
62
63
64
# File 'lib/instance_methods.rb', line 61

def increment_position
  return unless in_list?
  update_attribute position_column, self.send(position_column).to_i + 1
end

#insert_at(position = 1) ⇒ Object

Insert the item at the given position (defaults to the top position of 1).



8
9
10
# File 'lib/instance_methods.rb', line 8

def insert_at(position = 1)
  insert_at_position(position)
end

#last?Boolean

Return true if this object is the last in the list.

Returns:

  • (Boolean)


79
80
81
82
# File 'lib/instance_methods.rb', line 79

def last?
  return false unless in_list?
  self.send(position_column) == bottom_position_in_list
end

#lower_itemObject

Return the next lower item in the list.



93
94
95
96
97
98
# File 'lib/instance_methods.rb', line 93

def lower_item
  return nil unless in_list?
  acts_as_list_class.find(:first, :conditions =>
    "#{scope_condition} AND #{position_column} = #{(send(position_column).to_i + 1).to_s}"
  )
end

#move_higherObject

Swap positions with the next higher item, if one exists.



23
24
25
26
27
28
29
30
# File 'lib/instance_methods.rb', line 23

def move_higher
  return unless higher_item

  acts_as_list_class.transaction do
    higher_item.increment_position
    decrement_position
  end
end

#move_lowerObject

Swap positions with the next lower item, if one exists.



13
14
15
16
17
18
19
20
# File 'lib/instance_methods.rb', line 13

def move_lower
  return unless lower_item

  acts_as_list_class.transaction do
    lower_item.decrement_position
    increment_position
  end
end

#move_to_bottomObject

Move to the bottom of the list. If the item is already in the list, the items below it have their position adjusted accordingly.



34
35
36
37
38
39
40
# File 'lib/instance_methods.rb', line 34

def move_to_bottom
  return unless in_list?
  acts_as_list_class.transaction do
    decrement_positions_on_lower_items
    assume_bottom_position
  end
end

#move_to_topObject

Move to the top of the list. If the item is already in the list, the items above it have their position adjusted accordingly.



44
45
46
47
48
49
50
# File 'lib/instance_methods.rb', line 44

def move_to_top
  return unless in_list?
  acts_as_list_class.transaction do
    increment_positions_on_higher_items
    assume_top_position
  end
end

#remove_from_listObject

Removes the item from the list.



53
54
55
56
57
58
# File 'lib/instance_methods.rb', line 53

def remove_from_list
  if in_list?
    decrement_positions_on_lower_items
    update_attribute position_column, nil
  end
end